@@ -1,10 +1,13 @@
 import os
+import logging
 
-from elasticsearch import Elasticsearch, RequestsHttpConnection
+from elasticsearch import RequestsHttpConnection
 
 from automon.log.logger import Logging
 from automon.helpers.sanitation import Sanitation as S
 
+logging.getLogger('elasticsearch').setLevel(logging.ERROR)
+
 
 class ElasticsearchConfig:
     def __init__(self, endpoints: str = None, proxy=None,
@@ -15,9 +18,10 @@ class ElasticsearchConfig:
                  connection_class: RequestsHttpConnection = RequestsHttpConnection):
         self._log = Logging(ElasticsearchConfig.__name__, Logging.DEBUG)
 
-        self.es_hosts = S.list_from_string(endpoints) if endpoints else \
-            S.list_from_string(os.getenv('ELASTICSEARCH_ENDPOINT')) or \
-            S.list_from_string(os.getenv('ELASTICSEARCH_HOSTS')) or None
+        hosts = S.list_from_string(endpoints) or \
+                S.list_from_string(os.getenv('ELASTICSEARCH_HOSTS')) or ''
+        hosts = [{'host': x} for x in hosts]
+        self.es_hosts = hosts
 
         self.es_proxy = proxy
         self.request_timeout = request_timeout
@@ -26,18 +30,8 @@ class ElasticsearchConfig:
         self.verify_certs = verify_certs
         self.connection_class = connection_class
 
-        if self.es_hosts:
-            self.Elasticsearch = Elasticsearch(
-                hosts=self.es_hosts,
-                request_timeout=self.request_timeout,
-                http_auth=self.http_auth,
-                use_ssl=self.use_ssl,
-                verify_certs=self.verify_certs,
-                connection_class=self.connection_class)
-
-        else:
-            self.Elasticsearch = False
-            self._log.error(f'Missing ELASTICSEARCH_ENDPOINT, ELASTICSEARCH_ENDPOINT')
+        if not self.es_hosts:
+            self._log.error(f'Missing ELASTICSEARCH_HOSTS')
 
     def __eq__(self, other):
         if not isinstance(other, ElasticsearchConfig):
