@@ -36,7 +36,7 @@ class SlackError:
             self.errno = getattr(self._reason, 'errno', '')
             self.reason = getattr(self._reason, 'reason', '')
             self.strerror = getattr(self._reason, 'strerror', '')
-            self.verfify_code = getattr(self._reason, 'verify_code', '')
+            self.verify_code = getattr(self._reason, 'verify_code', '')
             self.verify_message = getattr(self._reason, 'verify_message', '')
 
         if self._response:
@@ -44,7 +44,7 @@ class SlackError:
 
             self.data = dict(getattr(self._response, 'data', ''))
             self.ok = self.data.get('ok', '')
-            self.error = self.data.get('error', '')
+            self.__error = self.data.get('error', '')
             self._needed = self.data.get('needed', '')
             self.provided = self.data.get('provided', '')
 
@@ -53,6 +53,16 @@ class SlackError:
             self.req_args = getattr(self._response, 'req_args', '')
             self.status_code = getattr(self._response, 'status_code', '')
 
+    def error(self):
+        if self._response:
+            return self.__error
+
+        if self._reason:
+            return self.strerror
+
+        log.info(f'{NotImplemented}')
+        return f'{self._error}'
+
     def needed(self):
         if self._response:
             return self._needed
@@ -125,47 +135,47 @@ class Slack(ConfigSlack):
     All Slack interactions
     """
 
-    def __init__(self, token: ConfigSlack.slack_token = None, username: str = None,
+    def __init__(self, token: str = ConfigSlack.slack_token, username: str = None,
                  channel: str = None, icon_emoji: str = None, icon_url: str = None):
 
-        self._log = Logging(Slack.__name__, Logging.DEBUG)
+        self._log = Logging(Slack.__name__, Logging.ERROR)
 
-        self.token = token if token else ConfigSlack().slack_token
+        self.token = ConfigSlack.slack_token or token
+        self.client = slack.WebClient(token=token)
 
-        if not self.token:
-            self._log.error(f'Missing SLACK_TOKEN')
-            self.client = None
-        else:
-            self.client = slack.WebClient(token=self.token)
+        try:
+            self.connected = True if self.client.auth_test() else False
+        except:
+            self.connected = False
 
         # TODO: use token to get bot info
-        self.username = username if username else self._get_bot_info()
-        # automonbot-test
-        self.channel = channel if channel else ''
-        self.icon_emoji = icon_emoji if icon_emoji else ''
-        self.icon_url = icon_url if icon_url else ''
+        self.username = ConfigSlack.slack_name or username or self._get_bot_info() or ''
+        self.channel = ConfigSlack.SLACK_DEFAULT_CHANNEL or channel or ''
+        self.icon_emoji = icon_emoji or ''
+        self.icon_url = icon_url or ''
 
         # start consumer
-        self._start_loop = AsyncStarter()
-        self.queue = self._start_loop.queue
-        asyncio.create_task(self._consumer())
+        self._eventloop = AsyncStarter()
+        self.queue = self._eventloop.queue
+        self.task = self._eventloop.create_task(self._consumer())
         self._stop = False
 
         # TODO: integrate slacklog
         # self.slacklog = SlackLogging(token)
 
-    def _get_bot_info(self: SlackResponse):
-        if self.client:
-            try:
-                name = BotInfo(self.client.bots_info()).name
-                self._log.debug(f'Bot name: {name}')
-                return name
-            except Exception as e:
-                error = SlackError(e)
-                self._log.error(
-                    f'''{self._get_bot_info.__name__}\tCouldn't get bot name, missing permission: {error.needed}''',
-                    enable_traceback=False)
-                return ''
+    def _get_bot_info(self):
+        if self.connected:
+            if self.client:
+                try:
+                    name = BotInfo(self.client.bots_info()).name
+                    self._log.debug(f'Bot name: {name}')
+                    return name
+                except Exception as e:
+                    error = SlackError(e)
+                    self._log.error(
+                        f'''[{self._get_bot_info.__name__}]\tCouldn't get bot name, missing permission: {error.needed}''',
+                        enable_traceback=False)
+                    return ''
         return ''
 
     def _run_until_complete(self):
@@ -244,7 +254,7 @@ class Slack(ConfigSlack):
 
             msg = f'{channel} @{self.username}: {text}'
 
-            while True:
+            while self.connected:
                 try:
                     self._log.debug(msg)
                     response = self.client.chat_postMessage(
