@@ -7,10 +7,11 @@ import datetime
 from swiftclient.service import SwiftService, SwiftError, ClientException
 
 from automon.log.logger import Logging, CRITICAL
-from automon.integrations.slack.slack_logger import SlackLogging
+from automon.integrations.swift.config import SwiftConfig
+from automon.integrations.slack.slack_logger import AsyncSlackLogging
 
 log = Logging(__name__, Logging.INFO)
-slacklog = SlackLogging(change_user=False, debug=False)
+slacklog = AsyncSlackLogging(change_user=False, debug=False)
 
 Logging('requests', CRITICAL)
 Logging('swiftclient', CRITICAL)
@@ -84,7 +85,7 @@ class SwiftError(object):
 
 class SwiftPage(SwiftService):
     def __init__(self, page: dict) -> SwiftService.list:
-        self._log = Logging(SwiftPage.__name__, Logging.DEBUG)
+        self._log = Logging(SwiftPage.__name__, Logging.ERROR)
 
         self._page = page
 
@@ -126,8 +127,8 @@ class SwiftPage(SwiftService):
 
     def list_gen(self) -> object or SwiftItem:
         if self.success:
-            for list in self.listing:
-                yield SwiftItem(list)
+            for LIST in self.listing:
+                yield SwiftItem(LIST)
         else:
             self._error_handler()
 
@@ -141,27 +142,25 @@ class SwiftList(SwiftService):
         always request a new SwiftService object
         see documentation
         """
-        self.log = Logging(SwiftList.__name__, Logging.DEBUG)
 
+        self._log = Logging(SwiftList.__name__, Logging.DEBUG)
         self.container = container
 
+    def list_gen(self) -> object or SwiftPage:
         with SwiftService() as swift:
             try:
-                # TODO: if swift auth fails, this won't complete
-                self.list_parts_gen = swift.list(container=container)
-                self.success = True
-                self.log.debug(f'succeeded, container: {container}')
-            except Exception as e:
-                self.success = False
-                self.log.error(f'failed, container: {container}, {e}')
+                list_parts_gen = swift.list(container=self.container)
 
-    def list_gen(self) -> object or SwiftPage:
-        try:
-            if self.success:
-                for page in self.list_parts_gen:
-                    yield SwiftPage(page)
-        except Exception as e:
-            self.log.error(f'page failed, {e}')
+                # TODO: need to check if gi_running is True when connected, or always False
+                if list_parts_gen.gi_running:
+                    for page in list_parts_gen:
+                        if page["success"]:
+                            yield SwiftPage(page)
+                        else:
+                            self._log.error(f'{page["error"]}')
+
+            except Exception as e:
+                self._log.error(f'page failed, {e}')
 
 
 class Swift:
@@ -169,10 +168,10 @@ class Swift:
         self._log = Logging(Swift.__name__, Logging.DEBUG)
 
     @staticmethod
-    def list_summary(self, files, folders):
+    def list_summary(files, folders):
         return files, folders
 
-    def list_container(self, container, summary=False, filter=None,
+    def list_container(self, container, summary=False, filter='',
                        separate=False) -> [SwiftItem]:
 
         self._log.info(f'listing {container} (filter: {filter})')
@@ -191,8 +190,9 @@ class Swift:
                 item_v1 = item.data()
                 item_v2 = item
 
-                if not item.filter(filter):
-                    continue
+                if filter:
+                    if not item.filter(filter):
+                        continue
 
                 swift_objects.append(item_v1)
                 swift_objects_v2.append(item_v2)
@@ -336,7 +336,7 @@ class Swift:
 
         # TODO: for some reason it's finished time shows 3 minutes, when debug shows 90 minutes
 
-        today = datetime.date.today()
+        today = f'{datetime.date.today()}'
         start_time = time.time()
         progress = 0
         retries = 0
@@ -410,7 +410,8 @@ class Swift:
 
                                     if i["success"]:
                                         self._log.info(
-                                            f'{percent}% ({progress}/{total}) created directory /{destination}/{today}/{name}')
+                                            f'{percent}% ({progress}/{total}) '
+                                            f'created directory /{destination}/{today}/{name}')
 
                                         retry = False
 
@@ -419,7 +420,7 @@ class Swift:
                                         slacklog.error(f'{SwiftError(i)}')
                                         retries += 1
 
-                            except:
+                            except Exception as _:
                                 self._log.error(item)
                                 slacklog.error(item)
                                 retries += 1
@@ -440,11 +441,13 @@ class Swift:
                                 if i["success"]:
                                     if i["action"] == "copy_object":
                                         self._log.info(
-                                            f'{percent}% ({progress}/{total}) copied {i["destination"]} from /{i["container"]}/{i["object"]}')
+                                            f'{percent}% ({progress}/{total}) '
+                                            f'copied {i["destination"]} from /{i["container"]}/{i["object"]}')
 
                                     if i["action"] == "create_container":
                                         self._log.info(
-                                            f'{percent}% ({progress}/{total}) container {i["container"]} created')
+                                            f'{percent}% ({progress}/{total}) '
+                                            f'container {i["container"]} created')
 
                                     retry = False
 
@@ -455,7 +458,7 @@ class Swift:
                                         if 'Authorization Failure. Authorization failed' in str(i):
                                             error = (
                                                 f'''This error happens every once in a while. I'm not really sure why, but might be some kind of stale timeout when SwiftService() isn't doing anything \n'''
-                                                f'{SwiftError(i).str}'
+                                                f'{SwiftError(i)}'
                                             )
                                         else:
                                             error = f'{SwiftError(i)}'
@@ -463,7 +466,7 @@ class Swift:
                                         slacklog.error(error)
                                         retries += 1
 
-                    except:
+                    except Exception as _:
                         slacklog.error(item)
                         slacklog.error()
                         retries += 1
@@ -474,19 +477,19 @@ class Swift:
         self._log.info('building backup summary')
 
         source_total_objects, \
-        source_total_dirs, \
-        source_objects, _, _ = source_stats
+            source_total_dirs, \
+            source_objects, _, _ = source_stats
 
         filter_destination_total_objects, \
-        filter_destination_total_dirs, \
-        filter_objects, _, _ = self.stats(destination, post_log=True, filter=today)
+            filter_destination_total_dirs, \
+            filter_objects, _, _ = self.stats(destination, post_log=True, filter=today)
 
         destination_total_objects, \
-        destination_total_dirs, \
-        destination_objects, _, _ = self.stats(destination, post_log=False)
+            destination_total_dirs, \
+            destination_objects, _, _ = self.stats(destination, post_log=False)
 
-        elapsed_time = time.time() - start_time
-        minutes = int(elapsed_time / 60)
+        # elapsed_time = time.time() - start_time
+        # minutes = int(elapsed_time / 60)
 
         msg = (
             f'*Backup Finished* \n'
@@ -574,7 +577,7 @@ class Swift:
 
         return missing_objects_list
 
-    def stats(self, container, filter=None, post_log=True, show_types=False):
+    def stats(self, container, filter='', post_log=True, show_types=False):
 
         self._log.info(f'stat {container} (filter: {filter})')
         slacklog.debug(f'stat {container} (filter: {filter})')
@@ -602,15 +605,15 @@ class Swift:
         objects = total_objects - total_dirs
 
         msg = ((f'Stats for {container}: \n'
-                f'>{total_objects} *total objects* \n'
-                f'>{objects} *objects* \n'
-                f'>{total_dirs} *dirs* \n'))
+                f'>{total_objects}*total objects* \n'
+                f'>{objects}*objects* \n'
+                f'>{total_dirs}*dirs* \n'))
 
         if filter:
             msg = ((f'Stats for {container} ({filter}): \n'
-                    f'>{total_objects} *total objects* \n'
-                    f'>{objects} *objects* \n'
-                    f'>{total_dirs} *dirs* \n'))
+                    f'>{total_objects}*total objects* \n'
+                    f'>{objects}*objects* \n'
+                    f'>{total_dirs}*dirs* \n'))
 
         if show_types:
             msg = msg + f'>*types:* `{list_types}` \n'
@@ -630,7 +633,7 @@ class Swift:
                     if i['success']:
                         self._log.info(f'deleted: {name}')
 
-            except:
+            except Exception as _:
                 slacklog.error()
 
     def delete(self, container, filter):
@@ -653,7 +656,7 @@ class Swift:
                         if i['success']:
                             self._log.info(f'{percent}% ({progress}/{deletion_count}) deleted: {name}')
 
-                except:
+                except Exception as _:
                     slacklog.error()
 
         slacklog.debug(
@@ -664,11 +667,11 @@ class Swift:
         with SwiftService() as swift:
             try:
                 slacklog.debug(f'*Deleting*: \n>{container}')
-                for i in swift.delete(container):
+                for _ in swift.delete(container):
                     self._log.info(f'deleting container: {container}')
                 slacklog.info(f'*Deleted*: \n>{container}')
 
-            except SwiftError as e:
+            except SwiftError as _:
                 slacklog.error()
 
     def restore(self):
